<?php
/**
 * XButtonColumn class file.
 *
 * @author rootbear
 * @license http://www.yiiframework.com/license/
 *
 * version 1.1   April 21, 2012 - support fliping yes/no image 
 * version 1.0.1 April 19, 2012
 * 
 * to-do: more customized buttons?
 * 
 */

Yii::import('zii.widgets.grid.CButtonColumn');

/**
 * XButtonColumn added extra button(s) - [yesno].
 *
 */
class XButtonColumn extends CButtonColumn
{
	//begin: version 1.1
	public $yesnoValue; //the value toggle yes or no image
	public $yesnoAction;
	
	public $yesValue = '1';   //value of yes, eg. 'Y', true
	public $noValue = '0';   //value of no, eg. 'N', false
	public $yesButtonLabel;
	public $yesButtonImageUrl;

	public $noButtonLabel;
	public $noButtonImageUrl;	
	//end: version 1.1
	
	public $yesnoButtonLabel;
	public $yesnoButtonImageUrl;
	public $yesnoButtonUrl='Yii::app()->controller->createUrl("{yesno}",array("id"=>$data->primaryKey))';
	public $yesnoButtonOptions=array('class'=>'update');
	public $yesnoConfirmation;
	public $afterYesno;
	
	private $_baseExtImageUrl;

	/**
	 * added new button {yesno}.
	 */
	public function init()
	{
		$this->initExtraButtons();
		parent::init();
	}

	/**
	 * for new button {yesno}.
	 */
	protected function initExtraButtons()
	{
		$image_path = dirname(__FILE__) . '/XButtonColumn/assets/images';
		$this->_baseExtImageUrl = Yii::app()->assetManager->publish( $image_path );
		
		$yesnoButtonUrl = str_replace("{yesno}", $this->yesnoAction, $this->yesnoButtonUrl);
	
		if($this->yesnoButtonLabel===null)
			$this->yesnoButtonLabel=Yii::t('zii','Flip Yes/No');
		if($this->yesButtonLabel===null)
			$this->yesButtonLabel=Yii::t('zii','Flip to No');
		if($this->noButtonLabel===null)
			$this->noButtonLabel=Yii::t('zii','Flip to Yes');
		if($this->yesnoButtonImageUrl===null)
			$this->yesnoButtonImageUrl=$this->_baseExtImageUrl.'/flag.png';
		if($this->yesButtonImageUrl===null)
			$this->yesButtonImageUrl=$this->_baseExtImageUrl.'/yes.png';
		if($this->noButtonImageUrl===null)
			$this->noButtonImageUrl=$this->_baseExtImageUrl.'/no.png';
		if($this->yesnoConfirmation===null)
			$this->yesnoConfirmation=Yii::t('zii','Are you sure you want to update this item?');

		foreach(array('yesno') as $id)
		{
			$button=array(
				'id'=>$id,
				'label'=>$this->{$id.'ButtonLabel'},
				'url'=>$yesnoButtonUrl,
				'imageUrl'=>$this->{$id.'ButtonImageUrl'},
				'options'=>$this->{$id.'ButtonOptions'},
			);
			if(isset($this->buttons[$id]))
				$this->buttons[$id]=array_merge($button,$this->buttons[$id]);
			else
				$this->buttons[$id]=$button;
		}

		if(!isset($this->buttons['yesno']['click']))
		{
			if(is_string($this->yesnoConfirmation))
				$confirmation="if(!confirm(".CJavaScript::encode($this->yesnoConfirmation).")) return false;";
			else
				$confirmation='';

			if(Yii::app()->request->enableCsrfValidation)
			{
				$csrfTokenName = Yii::app()->request->csrfTokenName;
				$csrfToken = Yii::app()->request->csrfToken;
				$csrf = "\n\t\tdata:{ '$csrfTokenName':'$csrfToken' },";
			}
			else
				$csrf = '';

			if($this->afterYesno===null)
				$this->afterYesno='function(){}';

			$this->buttons['yesno']['click']=<<<EOD
function() {
	$confirmation
	var th=this;
	var afterYesno=$this->afterYesno;
	$.fn.yiiGridView.update('{$this->grid->id}', {
		type:'POST',
		url:$(this).attr('href'),$csrf
		success:function(data) {
			$.fn.yiiGridView.update('{$this->grid->id}');
			afterYesno(th,true,data);
		},
		error:function(XHR) {
			return afterYesno(th,false,XHR);
		}
	});
	return false;
}
EOD;
		}
	}	
	

	/**
	 * flip yes/no image
	 */
	protected function renderButton($id,$button,$row,$data)
	{
		if (isset($button['id']) && $button['id'] == 'yesno') {
			if ($this->evaluateExpression($this->yesnoValue,array('row'=>$row,'data'=>$data)) == $this->yesValue){
				$button['imageUrl'] = $this->yesButtonImageUrl;
				$button['label'] = $this->yesButtonLabel;
			}else{
				$button['imageUrl'] = $this->noButtonImageUrl;
				$button['label'] = $this->noButtonLabel;
			}
		}
		parent::renderButton($id,$button,$row,$data);
	}
}